==> kdebindings-2.2.2.tar.bz2: kdebindings-2.2.2/kdejava/koala/org/kde/koala/KAboutDialogSignals.java <==
package org.kde.koala;
import org.kde.qt.*;


/** {@link KAboutDialog} emits these signals */
public interface KAboutDialogSignals {

/**  
 The Cancel button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotCancel} is not replaced.
     
*/
	void cancelClicked();

/**  
 Do not use this signal. Is is kept for compatibility reasons.
 Use {@link KAboutDialog#applyClicked} instead.
     
*/
	void apply();

/**  
 The User3 button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotUser3} is not replaced.
     
*/
	void user3Clicked();

/** 
 The dialog has finished.

 A dialog emits finished after a user clicks a button that ends
 the dialog.

 This signal is also emitted when you call {@link KAboutDialog#hide}

 If you have stored a pointer to the
 dialog do <em>not</em> try to delete the pointer in the slot that is
 connected to this signal.

 You should use {@link KAboutDialog#delayedDestruct} instead.
     
*/
	void finished();

/**  
 The background tile has changed.
     
*/
	void backgroundChanged();
	void destroyed();

/**  
 The User1 button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotUser1} is not replaced.
     
*/
	void user1Clicked();

/**  
 The Yes button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotYes} is not replaced.
     
*/
	void yesClicked();

/** 
 Send an email to this person.

 The application must provide the
  functionality.
   
*/
	void sendEmail( String name, String email );

/**  
 The Help button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotHelp} is not replaced.
     
*/
	void helpClicked();

/**  
 The Apply button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotApply} is not replaced.
     
*/
	void applyClicked();

/** 
 Emitted when the margin size and/or spacing size 
 have changed.

 Use {@link KAboutDialog#marginHint} and  {@link KAboutDialog#spacingHint} in your slot
 to get the new values.
     
*/
	void layoutHintChanged();

/**  
 The Close button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotClose} is not replaced.
     
*/
	void closeClicked();

/**  
 The OK button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotOk} is not replaced.
     
*/
	void okClicked();

/**  
 The Default button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotDefault} is not replaced.
     
*/
	void defaultClicked();

/** 
 The dialog is about to be hidden.

 A dialog is hidden after a user clicks a button that ends
 the dialog or when the user switches to another desktop or
 minimizes the dialog.
     
*/
	void hidden();

/** 
 Open the selected URL.
   
*/
	void openURL( String url );

/**  
 The Try button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotTry} is not replaced.
     
*/
	void tryClicked();

/**  
 The User2 button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotUser2} is not replaced.
     
*/
	void user2Clicked();

/**  
 The No button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotNo} is not replaced.
     
*/
	void noClicked();

/**  
 The detailsWidget is about to get shown. This is your last chance
 to call setDetailsWidget if you haven't done so yet.
     
*/
	void aboutToShowDetails();
}

==> kdebindings-3.0.1.tar.bz2: kdebindings-3.0.1/kdejava/koala/org/kde/koala/KAboutDialogSignals.java <==
package org.kde.koala;
import org.kde.qt.*;


/** {@link KAboutDialog} emits these signals */
public interface KAboutDialogSignals {

/** 
 The User3 button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotUser3} is not replaced.
     
*/
	void user3Clicked();
	void destroyed( QObject obj );

/** 
 The Yes button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotYes} is not replaced.
     
*/
	void yesClicked();

/** 
 Send an email to this person.

 The application must provide the
  functionality.
   
*/
	void sendEmail( String name, String email );

/** 
 The Help button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotHelp} is not replaced.
     
*/
	void helpClicked();

/** 
 The Apply button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotApply} is not replaced.
     
*/
	void applyClicked();

/** 
 The Default button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotDefault} is not replaced.
     
*/
	void defaultClicked();

/** 
 The Try button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotTry} is not replaced.
     
*/
	void tryClicked();

/** 
 The No button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotNo} is not replaced.
     
*/
	void noClicked();

/** 
 The detailsWidget is about to get shown. This is your last chance
 to call setDetailsWidget if you haven't done so yet.
     
*/
	void aboutToShowDetails();

/** 
 The Cancel button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotCancel} is not replaced.
     
*/
	void cancelClicked();

/** 
 Do not use this signal. Is is kept for compatibility reasons.
 Use {@link KAboutDialog#applyClicked} instead.
     
*/
	void apply();

/** 
 The dialog has finished.

 A dialog emits finished after a user clicks a button that ends
 the dialog.

 This signal is also emitted when you call {@link KAboutDialog#hide}

 If you have stored a pointer to the
 dialog do <em>not</em> try to delete the pointer in the slot that is
 connected to this signal.

 You should use {@link KAboutDialog#delayedDestruct} instead.
     
*/
	void finished();

/** 
 The background tile has changed.
     
*/
	void backgroundChanged();

/** 
 The User1 button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotUser1} is not replaced.
     
*/
	void user1Clicked();

/** 
 Emitted when the margin size and/or spacing size 
 have changed.

 Use {@link KAboutDialog#marginHint} and  {@link KAboutDialog#spacingHint} in your slot
 to get the new values.
     
*/
	void layoutHintChanged();

/** 
 The Close button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotClose} is not replaced.
     
*/
	void closeClicked();

/** 
 The OK button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotOk} is not replaced.
     
*/
	void okClicked();

/** 
 The dialog is about to be hidden.

 A dialog is hidden after a user clicks a button that ends
 the dialog or when the user switches to another desktop or
 minimizes the dialog.
     
*/
	void hidden();

/** 
 Open the selected URL.
   
*/
	void openURL( String url );

/** 
 The User2 button was pressed. This signal is only emitted if
 {@link KAboutDialog#slotUser2} is not replaced.
     
*/
	void user2Clicked();

/** 
 A page is about to be shown.
     
*/
	void aboutToShowPage( QWidget page );
}
